require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlrole',
  dscmeta_resource_friendly_name: 'SqlRole',
  dscmeta_resource_name: 'DSC_SqlRole',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.2.1',
  docs: 'The DSC SqlRole resource type.
         Automatically generated from version 14.2.1',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_servername: {
      type: 'Optional[String]',
      desc: 'The host name of the _SQL Server_ to be configured. Default value is `$env:COMPUTERNAME`.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: 'String',
      desc: 'The name of the _SQL Server_ instance to be configured.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: "An enumerated value that describes if the server role is added (`'Present'`) or dropped (`'Absent'`). Default value is `'Present'`.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_memberstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'The members the server role should include. This parameter will only add members to a server role. Can not be used at the same time as parameter **Members**.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_serverrolename: {
      type: 'String',
      desc: 'The name of of _SQL Server Database Engine_ role to add or remove.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_members: {
      type: 'Optional[Array[String]]',
      desc: 'The members the server role should have. This parameter will replace all the current server role members with the specified members.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_memberstoexclude: {
      type: 'Optional[Array[String]]',
      desc: "The members the server role should exclude. This parameter will only remove members from a server role. Can only be used when parameter **Ensure** is set to `'Present'`. Can not be used at the same time as parameter **Members**.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
